apply_weighting_method: Apply Weighting Method to Values

View source: R/weighting.R

apply_weighting_methodR Documentation

Apply Weighting Method to Values

Description

Internal utility function that applies various weighting methods to a vector. Used by other weighting functions.

Usage

apply_weighting_method(values, method = "rank", preference_ascending = TRUE)

Arguments

values

Named numeric vector of values to weight

preference_ascending

TRUE = prefer lower values, FALSE = prefer higher

Value

Named numeric vector of weights that sum to 1


PortfolioTesteR documentation built on Nov. 5, 2025, 5:23 p.m.