ml_ic_series_on_scores: Rank-IC series computed on score (rebalance) dates

View source: R/ml_helper.R

ml_ic_series_on_scoresR Documentation

Rank-IC series computed on score (rebalance) dates

Description

Wrapper around ic_series() that first filters scores to formation dates using an internal filter that keeps rows where at least one score is finite.

Usage

ml_ic_series_on_scores(scores_dt, labels_dt, method = "spearman")

Arguments

scores_dt

Scores table (wide).

labels_dt

Labels table (wide).

method

Correlation method; "spearman" (default) or "pearson".

Value

A data frame/data.table with Date and IC values.

Examples

## Not run: 
ic <- ml_ic_series_on_scores(res_xgb$scores, Y, method = "spearman")

## End(Not run)

PortfolioTesteR documentation built on Nov. 5, 2025, 5:23 p.m.