| sample_prices_daily | R Documentation |
Daily closing prices for 20 stocks from 2017-2019. Contains the same symbols as sample_prices_weekly but at daily frequency for more granular analysis and performance calculations.
data(sample_prices_daily)
A data.table with 754 rows and 21 columns:
Date object, trading date
Apple Inc. adjusted closing price
Amazon.com Inc. adjusted closing price
Boeing Co. adjusted closing price
Bank of America Corp. adjusted closing price
Additional stock symbols with adjusted closing prices
Yahoo Finance historical data, adjusted for splits and dividends
data(sample_prices_daily)
head(sample_prices_daily)
# Get date range
range(sample_prices_daily$Date)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.