| sample_sp500_sectors | R Documentation |
Sector classifications for the stock symbols in the sample datasets. Note: ETFs (SPY, QQQ, etc.) are not included as they represent indices or sectors themselves rather than individual companies.
data(sample_sp500_sectors)
A data.table with 18 rows and 2 columns:
Character, stock ticker symbol
Character, GICS sector classification
S&P 500 constituent data
data(sample_sp500_sectors)
head(sample_sp500_sectors)
# Count stocks per sector
table(sample_sp500_sectors$Sector)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.