View source: R/data_adapters.R
| standardize_data_format | R Documentation |
Internal function that converts various data formats to standard wide format with Date column and symbol columns.
standardize_data_format(
data,
date_col = "date",
symbol_col = "symbol",
price_col = "price",
symbol_order = NULL
)
data |
Input data in long or wide format |
date_col |
Name of date column |
symbol_col |
Name of symbol column (for long format) |
price_col |
Name of price column (for long format) |
symbol_order |
Optional ordering for symbols |
Standardized data.table
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.