| apply_weighting_method | R Documentation |
Internal utility function that applies various weighting methods to a vector. Used by other weighting functions.
apply_weighting_method(values, method = "rank", preference_ascending = TRUE)
values |
Named numeric vector of values to weight |
preference_ascending |
TRUE = prefer lower values, FALSE = prefer higher |
Named numeric vector of weights that sum to 1
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.