Learn R Programming

PortfolioTesteR (version 0.1.4)

ml_ic_series_on_scores: Rank-IC series computed on score (rebalance) dates

Description

Wrapper around ic_series() that first filters scores to formation dates using an internal filter that keeps rows where at least one score is finite.

Usage

ml_ic_series_on_scores(scores_dt, labels_dt, method = "spearman")

Value

A data frame/data.table with Date and IC values.

Arguments

scores_dt

Scores table (wide).

labels_dt

Labels table (wide).

method

Correlation method; "spearman" (default) or "pearson".

Examples

Run this code
if (FALSE) {
ic <- ml_ic_series_on_scores(res_xgb$scores, Y, method = "spearman")
}

Run the code above in your browser using DataLab