View source: R/performance_analytics.R
| validate_performance_inputs | R Documentation |
data("sample_prices_weekly") Checks that backtest result and daily prices are properly formatted with matching symbols and appropriate date coverage.
validate_performance_inputs(backtest_result, daily_prices, benchmark_symbol)
backtest_result |
Backtest result object data("sample_prices_weekly") |
daily_prices |
Daily price data |
benchmark_symbol |
Benchmark symbol |
TRUE if valid, stops with error if not
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.